Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(658)

Unified Diff: content/public/android/java/src/org/chromium/content/browser/VibrationProvider.java

Issue 23496051: Make VibrationMessageFilter available to other platforms. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebased and added contact info for override APIs. Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/android/java/src/org/chromium/content/browser/VibrationProvider.java
diff --git a/content/public/android/java/src/org/chromium/content/browser/VibrationMessageFilter.java b/content/public/android/java/src/org/chromium/content/browser/VibrationProvider.java
similarity index 77%
rename from content/public/android/java/src/org/chromium/content/browser/VibrationMessageFilter.java
rename to content/public/android/java/src/org/chromium/content/browser/VibrationProvider.java
index fdd58cf1d8bed7b61319303c4e671c27f7e3cbe7..10edcbb1737cefe62d0a4d1f7d96ee876a749bfe 100644
--- a/content/public/android/java/src/org/chromium/content/browser/VibrationMessageFilter.java
+++ b/content/public/android/java/src/org/chromium/content/browser/VibrationProvider.java
@@ -12,17 +12,17 @@ import org.chromium.base.CalledByNative;
import org.chromium.base.JNINamespace;
/**
* This is the implementation of the C++ counterpart VibrationMessageFilter.
*/
@JNINamespace("content")
-class VibrationMessageFilter {
+class VibrationProvider {
private final AudioManager mAudioManager;
private final Vibrator mVibrator;
@CalledByNative
- private static VibrationMessageFilter create(Context context) {
- return new VibrationMessageFilter(context);
+ private static VibrationProvider create(Context context) {
+ return new VibrationProvider(context);
}
@CalledByNative
@@ -36,7 +36,7 @@ class VibrationMessageFilter {
mVibrator.cancel();
}
- private VibrationMessageFilter(Context context) {
+ private VibrationProvider(Context context) {
mAudioManager = (AudioManager) context.getSystemService(Context.AUDIO_SERVICE);
mVibrator = (Vibrator) context.getSystemService(Context.VIBRATOR_SERVICE);
}
@@ -12,17 +12,17 @@ import org.chromium.base.CalledByNative;
import org.chromium.base.JNINamespace;
/**
- * This is the implementation of the C++ counterpart VibrationMessageFilter.
+ * This is the implementation of the C++ counterpart VibrationProvider.
*/

Powered by Google App Engine
This is Rietveld 408576698